@@ -5,16 +5,19 @@ use IPDR::Collection::Client;
 
 my $ipdr_client = new IPDR::Collection::Client (
 			[
-			VendorID => 'IPDR Client',
-			ServerIP => '10.1.1.1',
-			ServerPort => '10000',
+			VendorID => 'VirginMedia IPDR Client',
+			ServerIP => '80.194.79.221',
+			ServerPort => '14000',
 			KeepAlive => 60,
 			Capabilities => 0x01,
+			DEBUG => 5,
 			DataHandler => \&display_data,
 			Timeout => 2,
 			]
 			);
 
+#DEBUG => 5
+
 # We send a connect message to the IPDR server
 $ipdr_client->connect();
 
@@ -28,6 +31,8 @@ if ( !$ipdr_client->connected )
 # We now send a connect message 
 $ipdr_client->check_data_available();
 
+print "Error was '".$ipdr_client->get_error()."'\n";
+
 exit(0);
 
 sub display_data
@@ -36,6 +41,15 @@ my ( $remote_ip ) = shift;
 my ( $remote_port ) = shift;
 my ( $data ) = shift;
 
+foreach my $sequence ( sort { $a<=>$b } keys %{$data} )
+	{
+	print "Sequence  is '$sequence'\n";
+	foreach my $attribute ( keys %{${$data}{$sequence}} )
+		{
+		print "Sequence '$sequence' attribute '$attribute' value '${$data}{$sequence}{$attribute}'\n";
+		}
+	}
+
 }
 
 
